@@ -1,22 +1,45 @@
 # This file is dual licensed under the terms of the Apache License, Version
 # 2.0, and the BSD License. See the LICENSE file in the root of this repository
 # for complete details.
-from __future__ import absolute_import, division, print_function
+
+from __future__ import annotations
 
 import itertools
 import operator
+import sys
+import typing
 
 import pretend
 import pytest
 
-from packaging.version import Version, LegacyVersion, InvalidVersion, parse
+from packaging.version import InvalidVersion, Version, _VersionReplace, parse
+
+if typing.TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from typing_extensions import Self, Unpack
+
+if sys.version_info >= (3, 13):
+    from copy import replace
+else:
+    T = typing.TypeVar("T")
+
+    class SupportsReplace(typing.Protocol):
+        def __replace__(self, **kwargs: Unpack[_VersionReplace]) -> Self: ...
+
+    S = typing.TypeVar("S", bound="SupportsReplace")
+
+    def replace(item: S, **kwargs: Unpack[_VersionReplace]) -> S:
+        return item.__replace__(**kwargs)
 
 
-@pytest.mark.parametrize(
-    ("version", "klass"), [("1.0", Version), ("1-1-1", LegacyVersion)]
-)
-def test_parse(version, klass):
-    assert isinstance(parse(version), klass)
+def test_parse() -> None:
+    assert isinstance(parse("1.0"), Version)
+
+
+def test_parse_raises() -> None:
+    with pytest.raises(InvalidVersion):
+        parse("lolwat")
 
 
 # This list must be in the correct sorting order
@@ -82,9 +105,13 @@ VERSIONS = [
 
 class TestVersion:
     @pytest.mark.parametrize("version", VERSIONS)
-    def test_valid_versions(self, version):
+    def test_valid_versions(self, version: str) -> None:
         Version(version)
 
+    def test_match_args(self) -> None:
+        assert Version.__match_args__ == ("_str",)
+        assert Version("1.2")._str == "1.2"
+
     @pytest.mark.parametrize(
         "version",
         [
@@ -98,7 +125,7 @@ class TestVersion:
             "1.0+1+1",
         ],
     )
-    def test_invalid_versions(self, version):
+    def test_invalid_versions(self, version: str) -> None:
         with pytest.raises(InvalidVersion):
             Version(version)
 
@@ -109,13 +136,11 @@ class TestVersion:
             ("1.0dev", "1.0.dev0"),
             ("1.0.dev", "1.0.dev0"),
             ("1.0dev1", "1.0.dev1"),
-            ("1.0dev", "1.0.dev0"),
             ("1.0-dev", "1.0.dev0"),
             ("1.0-dev1", "1.0.dev1"),
             ("1.0DEV", "1.0.dev0"),
             ("1.0.DEV", "1.0.dev0"),
             ("1.0DEV1", "1.0.dev1"),
-            ("1.0DEV", "1.0.dev0"),
             ("1.0.DEV1", "1.0.dev1"),
             ("1.0-DEV", "1.0.dev0"),
             ("1.0-DEV1", "1.0.dev1"),
@@ -186,13 +211,11 @@ class TestVersion:
             ("1.0post", "1.0.post0"),
             ("1.0.post", "1.0.post0"),
             ("1.0post1", "1.0.post1"),
-            ("1.0post", "1.0.post0"),
             ("1.0-post", "1.0.post0"),
             ("1.0-post1", "1.0.post1"),
             ("1.0POST", "1.0.post0"),
             ("1.0.POST", "1.0.post0"),
             ("1.0POST1", "1.0.post1"),
-            ("1.0POST", "1.0.post0"),
             ("1.0r", "1.0.post0"),
             ("1.0rev", "1.0.post0"),
             ("1.0.POST1", "1.0.post1"),
@@ -220,7 +243,7 @@ class TestVersion:
             ("   v1.0\t\n", "1.0"),
         ],
     )
-    def test_normalized_versions(self, version, normalized):
+    def test_normalized_versions(self, version: str, normalized: str) -> None:
         assert str(Version(version)) == normalized
 
     @pytest.mark.parametrize(
@@ -275,15 +298,15 @@ class TestVersion:
             ("7!1.1.dev1", "7!1.1.dev1"),
         ],
     )
-    def test_version_str_repr(self, version, expected):
+    def test_version_str_repr(self, version: str, expected: str) -> None:
         assert str(Version(version)) == expected
-        assert repr(Version(version)) == "<Version({0})>".format(repr(expected))
+        assert repr(Version(version)) == f"<Version({expected!r})>"
 
-    def test_version_rc_and_c_equals(self):
+    def test_version_rc_and_c_equals(self) -> None:
         assert Version("1.0rc1") == Version("1.0c1")
 
     @pytest.mark.parametrize("version", VERSIONS)
-    def test_version_hash(self, version):
+    def test_version_hash(self, version: str) -> None:
         assert hash(Version(version)) == hash(Version(version))
 
     @pytest.mark.parametrize(
@@ -320,7 +343,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", "1!1.0.post5"),
         ],
     )
-    def test_version_public(self, version, public):
+    def test_version_public(self, version: str, public: str) -> None:
         assert Version(version).public == public
 
     @pytest.mark.parametrize(
@@ -357,7 +380,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", "1!1.0"),
         ],
     )
-    def test_version_base_version(self, version, base_version):
+    def test_version_base_version(self, version: str, base_version: str) -> None:
         assert Version(version).base_version == base_version
 
     @pytest.mark.parametrize(
@@ -394,7 +417,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", 1),
         ],
     )
-    def test_version_epoch(self, version, epoch):
+    def test_version_epoch(self, version: str, epoch: int) -> None:
         assert Version(version).epoch == epoch
 
     @pytest.mark.parametrize(
@@ -431,7 +454,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", (1, 0)),
         ],
     )
-    def test_version_release(self, version, release):
+    def test_version_release(self, version: str, release: tuple[int, int]) -> None:
         assert Version(version).release == release
 
     @pytest.mark.parametrize(
@@ -468,7 +491,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", "deadbeef"),
         ],
     )
-    def test_version_local(self, version, local):
+    def test_version_local(self, version: str, local: str | None) -> None:
         assert Version(version).local == local
 
     @pytest.mark.parametrize(
@@ -505,7 +528,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", None),
         ],
     )
-    def test_version_pre(self, version, pre):
+    def test_version_pre(self, version: str, pre: None | tuple[str, int]) -> None:
         assert Version(version).pre == pre
 
     @pytest.mark.parametrize(
@@ -535,7 +558,7 @@ class TestVersion:
             ("1.0.post1+dev", False),
         ],
     )
-    def test_version_is_prerelease(self, version, expected):
+    def test_version_is_prerelease(self, version: str, expected: bool) -> None:
         assert Version(version).is_prerelease is expected
 
     @pytest.mark.parametrize(
@@ -572,7 +595,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", None),
         ],
     )
-    def test_version_dev(self, version, dev):
+    def test_version_dev(self, version: str, dev: int | None) -> None:
         assert Version(version).dev == dev
 
     @pytest.mark.parametrize(
@@ -609,7 +632,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", False),
         ],
     )
-    def test_version_is_devrelease(self, version, expected):
+    def test_version_is_devrelease(self, version: str, expected: bool) -> None:
         assert Version(version).is_devrelease is expected
 
     @pytest.mark.parametrize(
@@ -646,7 +669,7 @@ class TestVersion:
             ("1!1.0.post5+deadbeef", 5),
         ],
     )
-    def test_version_post(self, version, post):
+    def test_version_post(self, version: str, post: int | None) -> None:
         assert Version(version).post == post
 
     @pytest.mark.parametrize(
@@ -659,15 +682,14 @@ class TestVersion:
             ("1.0.post1", True),
         ],
     )
-    def test_version_is_postrelease(self, version, expected):
+    def test_version_is_postrelease(self, version: str, expected: bool) -> None:
         assert Version(version).is_postrelease is expected
 
     @pytest.mark.parametrize(
         ("left", "right", "op"),
         # Below we'll generate every possible combination of VERSIONS that
         # should be True for the given operator
-        itertools.chain(
-            *
+        itertools.chain.from_iterable(
             # Verify that the less than (<) operator works correctly
             [
                 [(x, y, operator.lt) for y in VERSIONS[i + 1 :]]
@@ -702,15 +724,16 @@ class TestVersion:
             ]
         ),
     )
-    def test_comparison_true(self, left, right, op):
+    def test_comparison_true(
+        self, left: str, right: str, op: Callable[[Version, Version], bool]
+    ) -> None:
         assert op(Version(left), Version(right))
 
     @pytest.mark.parametrize(
         ("left", "right", "op"),
         # Below we'll generate every possible combination of VERSIONS that
         # should be False for the given operator
-        itertools.chain(
-            *
+        itertools.chain.from_iterable(
             # Verify that the less than (<) operator works correctly
             [
                 [(x, y, operator.lt) for y in VERSIONS[: i + 1]]
@@ -745,144 +768,266 @@ class TestVersion:
             ]
         ),
     )
-    def test_comparison_false(self, left, right, op):
+    def test_comparison_false(
+        self, left: str, right: str, op: Callable[[Version, Version], bool]
+    ) -> None:
         assert not op(Version(left), Version(right))
 
+    @pytest.mark.parametrize("op", ["lt", "le", "eq", "ge", "gt", "ne"])
+    def test_dunder_op_returns_notimplemented(self, op: str) -> None:
+        method = getattr(Version, f"__{op}__")
+        assert method(Version("1"), 1) is NotImplemented
+
     @pytest.mark.parametrize(("op", "expected"), [("eq", False), ("ne", True)])
-    def test_compare_other(self, op, expected):
-        other = pretend.stub(**{"__{0}__".format(op): lambda other: NotImplemented})
+    def test_compare_other(self, op: str, expected: bool) -> None:
+        other = pretend.stub(**{f"__{op}__": lambda _: NotImplemented})
 
         assert getattr(operator, op)(Version("1"), other) is expected
 
-    def test_compare_legacyversion_version(self):
-        result = sorted([Version("0"), LegacyVersion("1")])
-        assert result == [LegacyVersion("1"), Version("0")]
-
-    def test_major_version(self):
+    def test_major_version(self) -> None:
         assert Version("2.1.0").major == 2
 
-    def test_minor_version(self):
+    def test_minor_version(self) -> None:
         assert Version("2.1.0").minor == 1
         assert Version("2").minor == 0
 
-    def test_micro_version(self):
+    def test_micro_version(self) -> None:
         assert Version("2.1.3").micro == 3
         assert Version("2.1").micro == 0
         assert Version("2").micro == 0
 
+    # Tests for replace() method
+    def test_replace_no_args(self) -> None:
+        """replace() with no arguments should return an equivalent version"""
+        v = Version("1.2.3a1.post2.dev3+local")
+        v_replaced = replace(v)
+        assert v == v_replaced
+        assert str(v) == str(v_replaced)
 
-LEGACY_VERSIONS = ["foobar", "a cat is fine too", "lolwut", "1-0", "2.0-a1"]
+    def test_replace_epoch(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, epoch=2)) == "2!1.2.3"
+        assert replace(v, epoch=0).epoch == 0
+
+        v_with_epoch = Version("1!1.2.3")
+        assert str(replace(v_with_epoch, epoch=2)) == "2!1.2.3"
+        assert str(replace(v_with_epoch, epoch=None)) == "1.2.3"
+
+    def test_replace_release_tuple(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, release=(2, 0, 0))) == "2.0.0"
+        assert str(replace(v, release=(1,))) == "1"
+        assert str(replace(v, release=(1, 2, 3, 4, 5))) == "1.2.3.4.5"
+
+    def test_replace_release_none(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, release=None)) == "0"
+
+    def test_replace_pre_alpha(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, pre=("a", 1))) == "1.2.3a1"
+        assert str(replace(v, pre=("a", 0))) == "1.2.3a0"
+
+    def test_replace_pre_alpha_none(self) -> None:
+        v = Version("1.2.3a1")
+        assert str(replace(v, pre=None)) == "1.2.3"
+
+    def test_replace_pre_beta(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, pre=("b", 1))) == "1.2.3b1"
+        assert str(replace(v, pre=("b", 0))) == "1.2.3b0"
+
+    def test_replace_pre_beta_none(self) -> None:
+        v = Version("1.2.3b1")
+        assert str(replace(v, pre=None)) == "1.2.3"
+
+    def test_replace_pre_rc(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, pre=("rc", 1))) == "1.2.3rc1"
+        assert str(replace(v, pre=("rc", 0))) == "1.2.3rc0"
+
+    def test_replace_pre_rc_none(self) -> None:
+        v = Version("1.2.3rc1")
+        assert str(replace(v, pre=None)) == "1.2.3"
+
+    def test_replace_post(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, post=1)) == "1.2.3.post1"
+        assert str(replace(v, post=0)) == "1.2.3.post0"
+
+    def test_replace_post_none(self) -> None:
+        v = Version("1.2.3.post1")
+        assert str(replace(v, post=None)) == "1.2.3"
+
+    def test_replace_dev(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, dev=1)) == "1.2.3.dev1"
+        assert str(replace(v, dev=0)) == "1.2.3.dev0"
+
+    def test_replace_dev_none(self) -> None:
+        v = Version("1.2.3.dev1")
+        assert str(replace(v, dev=None)) == "1.2.3"
+
+    def test_replace_local_string(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, local="abc")) == "1.2.3+abc"
+        assert str(replace(v, local="abc.123")) == "1.2.3+abc.123"
+        assert str(replace(v, local="abc-123")) == "1.2.3+abc.123"
+
+    def test_replace_local_none(self) -> None:
+        v = Version("1.2.3+local")
+        assert str(replace(v, local=None)) == "1.2.3"
+
+    def test_replace_multiple_components(self) -> None:
+        v = Version("1.2.3")
+        assert str(replace(v, pre=("a", 1), post=1)) == "1.2.3a1.post1"
+        assert str(replace(v, release=(2, 0, 0), pre=("b", 2), dev=1)) == "2.0.0b2.dev1"
+        assert str(replace(v, epoch=1, release=(3, 0), local="abc")) == "1!3.0+abc"
+
+    def test_replace_clear_all_optional(self) -> None:
+        v = Version("1!1.2.3a1.post2.dev3+local")
+        cleared = replace(v, epoch=None, pre=None, post=None, dev=None, local=None)
+        assert str(cleared) == "1.2.3"
+
+    def test_replace_preserves_comparison(self) -> None:
+        v1 = Version("1.2.3")
+        v2 = Version("1.2.4")
+
+        v1_new = replace(v1, release=(1, 2, 4))
+        assert v1_new == v2
+        assert v1 < v2
+        assert v1_new >= v2
+
+    def test_replace_preserves_hash(self) -> None:
+        v1 = Version("1.2.3")
+        v2 = replace(v1, release=(1, 2, 3))
+        assert hash(v1) == hash(v2)
+
+        v3 = replace(v1, release=(2, 0, 0))
+        assert hash(v1) != hash(v3)
+
+    def test_replace_returns_same_instance_when_unchanged(self) -> None:
+        """replace() returns the exact same object when no components change"""
+        v = Version("1.2.3a1.post2.dev3+local")
+        assert replace(v) is v
+        assert replace(v, epoch=0) is v
+        assert replace(v, release=(1, 2, 3)) is v
+        assert replace(v, pre=("a", 1)) is v
+        assert replace(v, post=2) is v
+        assert replace(v, dev=3) is v
+        assert replace(v, local="local") is v
+
+    def test_replace_change_pre_type(self) -> None:
+        """Can change from one pre-release type to another"""
+        v = Version("1.2.3a1")
+        assert str(replace(v, pre=("b", 2))) == "1.2.3b2"
+        assert str(replace(v, pre=("rc", 1))) == "1.2.3rc1"
+
+        v2 = Version("1.2.3rc5")
+        assert str(replace(v2, pre=("a", 0))) == "1.2.3a0"
+
+    def test_replace_invalid_epoch_type(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="epoch must be non-negative"):
+            replace(v, epoch="1")  # type: ignore[arg-type]
+
+    def test_replace_invalid_post_type(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="post must be non-negative"):
+            replace(v, post="1")  # type: ignore[arg-type]
+
+    def test_replace_invalid_dev_type(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="dev must be non-negative"):
+            replace(v, dev="1")  # type: ignore[arg-type]
+
+    def test_replace_invalid_epoch_negative(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="epoch must be non-negative"):
+            replace(v, epoch=-1)
+
+    def test_replace_invalid_release_empty(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="release must be a non-empty tuple"):
+            replace(v, release=())
+
+    def test_replace_invalid_release_tuple_content(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(
+            InvalidVersion, match="release must be a non-empty tuple of non-negative"
+        ):
+            replace(v, release=(1, -2, 3))
+
+    def test_replace_invalid_pre_negative(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="pre must be a tuple"):
+            replace(v, pre=("a", -1))
+
+    def test_replace_invalid_pre_type(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="pre must be a tuple"):
+            replace(v, pre=("x", 1))  # type: ignore[arg-type]
+
+    def test_replace_invalid_pre_format(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="pre must be a tuple"):
+            replace(v, pre="a1")  # type: ignore[arg-type]
+        with pytest.raises(InvalidVersion, match="pre must be a tuple"):
+            replace(v, pre=("a",))  # type: ignore[arg-type]
+        with pytest.raises(InvalidVersion, match="pre must be a tuple"):
+            replace(v, pre=("a", 1, 2))  # type: ignore[arg-type]
+
+    def test_replace_invalid_post_negative(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="post must be non-negative"):
+            replace(v, post=-1)
+
+    def test_replace_invalid_dev_negative(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(InvalidVersion, match="dev must be non-negative"):
+            replace(v, dev=-1)
+
+    def test_replace_invalid_local_string(self) -> None:
+        v = Version("1.2.3")
+        with pytest.raises(
+            InvalidVersion, match="local must be a valid version string"
+        ):
+            replace(v, local="abc+123")
+        with pytest.raises(
+            InvalidVersion, match="local must be a valid version string"
+        ):
+            replace(v, local="+abc")
 
 
-class TestLegacyVersion:
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_valid_legacy_versions(self, version):
-        LegacyVersion(version)
+# Taken from hatchling 1.28
+def reset_version_parts(version: Version, **kwargs: typing.Any) -> None:  # noqa: ANN401
+    # https://github.com/pypa/packaging/blob/20.9/packaging/version.py#L301-L310
+    internal_version = version._version
+    parts: dict[str, typing.Any] = {}
+    ordered_part_names = ("epoch", "release", "pre", "post", "dev", "local")
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_str_repr(self, version):
-        assert str(LegacyVersion(version)) == version
-        assert repr(LegacyVersion(version)) == "<LegacyVersion({0})>".format(
-            repr(version)
-        )
+    reset = False
+    for part_name in ordered_part_names:
+        if reset:
+            parts[part_name] = kwargs.get(part_name)
+        elif part_name in kwargs:
+            parts[part_name] = kwargs[part_name]
+            reset = True
+        else:
+            parts[part_name] = getattr(internal_version, part_name)
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_hash(self, version):
-        assert hash(LegacyVersion(version)) == hash(LegacyVersion(version))
+    version._version = type(internal_version)(**parts)
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_public(self, version):
-        assert LegacyVersion(version).public == version
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_base_version(self, version):
-        assert LegacyVersion(version).base_version == version
+# These will be deprecated in 26.1, and removed in the future
+def test_deprecated__version() -> None:
+    v = Version("1.2.3")
+    with pytest.warns(DeprecationWarning, match="is private"):
+        assert v._version.release == (1, 2, 3)
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_epoch(self, version):
-        assert LegacyVersion(version).epoch == -1
 
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_release(self, version):
-        assert LegacyVersion(version).release is None
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_local(self, version):
-        assert LegacyVersion(version).local is None
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_pre(self, version):
-        assert LegacyVersion(version).pre is None
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_is_prerelease(self, version):
-        assert not LegacyVersion(version).is_prerelease
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_dev(self, version):
-        assert LegacyVersion(version).dev is None
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_is_devrelease(self, version):
-        assert not LegacyVersion(version).is_devrelease
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_post(self, version):
-        assert LegacyVersion(version).post is None
-
-    @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
-    def test_legacy_version_is_postrelease(self, version):
-        assert not LegacyVersion(version).is_postrelease
-
-    @pytest.mark.parametrize(
-        ("left", "right", "op"),
-        # Below we'll generate every possible combination of
-        # VERSIONS + LEGACY_VERSIONS that should be True for the given operator
-        itertools.chain(
-            *
-            # Verify that the equal (==) operator works correctly
-            [[(x, x, operator.eq) for x in VERSIONS + LEGACY_VERSIONS]]
-            +
-            # Verify that the not equal (!=) operator works correctly
-            [
-                [
-                    (x, y, operator.ne)
-                    for j, y in enumerate(VERSIONS + LEGACY_VERSIONS)
-                    if i != j
-                ]
-                for i, x in enumerate(VERSIONS + LEGACY_VERSIONS)
-            ]
-        ),
-    )
-    def test_comparison_true(self, left, right, op):
-        assert op(LegacyVersion(left), LegacyVersion(right))
-
-    @pytest.mark.parametrize(
-        ("left", "right", "op"),
-        # Below we'll generate every possible combination of
-        # VERSIONS + LEGACY_VERSIONS that should be False for the given
-        # operator
-        itertools.chain(
-            *
-            # Verify that the equal (==) operator works correctly
-            [
-                [
-                    (x, y, operator.eq)
-                    for j, y in enumerate(VERSIONS + LEGACY_VERSIONS)
-                    if i != j
-                ]
-                for i, x in enumerate(VERSIONS + LEGACY_VERSIONS)
-            ]
-            +
-            # Verify that the not equal (!=) operator works correctly
-            [[(x, x, operator.ne) for x in VERSIONS + LEGACY_VERSIONS]]
-        ),
-    )
-    def test_comparison_false(self, left, right, op):
-        assert not op(LegacyVersion(left), LegacyVersion(right))
-
-    @pytest.mark.parametrize(("op", "expected"), [("eq", False), ("ne", True)])
-    def test_compare_other(self, op, expected):
-        other = pretend.stub(**{"__{0}__".format(op): lambda other: NotImplemented})
-
-        assert getattr(operator, op)(LegacyVersion("1"), other) is expected
+def test_hatchling_usage__version() -> None:
+    v = Version("2.3.4")
+    with pytest.warns(DeprecationWarning, match="is private"):
+        reset_version_parts(v, post=("post", 1))
+    assert v == Version("2.3.4.post1")
